==> org-lsst-sal-camera-2.5.0-sources.jar: org/lsst/sal/camera/event/Refrig_Cryo4_CompLimitsConfigurationEvent.java <==
package org.lsst.sal.camera.event;

import org.lsst.sal.camera.CameraEvent;

public class Refrig_Cryo4_CompLimitsConfigurationEvent extends CameraEvent {
  private final String version;

  private final double cmprPowerDelayLimit;

  private final int cmprPowerDelayTime;

  private final double cmprPowerImmedLimit;

  private final double coldTempImmedLimit;

  private final double discPressDelayLimit;

  private final int discPressDelayTime;

  private final double discPressImmedLimit;

  private final double discTempDelayLimit;

  private final int discTempDelayTime;

  private final double discTempImmedLimit;

  private final double discTempLowImmedLimit;

  private final double heaterTempLimit;

  private final double liquidTempDelayLimit;

  private final int liquidTempDelayTime;

  private final double liquidTempImmedLimit;

  private final double orificeOffPress;

  private final double orificeOnPress;

  private final double phaseSepTempDelayLimit;

  private final int phaseSepTempDelayTime;

  private final double pressDiffImmedLimit;

  private final double suctTempImmedLimit;

  public Refrig_Cryo4_CompLimitsConfigurationEvent(int priority, String version,
      double cmprPowerDelayLimit, int cmprPowerDelayTime, double cmprPowerImmedLimit,
      double coldTempImmedLimit, double discPressDelayLimit, int discPressDelayTime,
      double discPressImmedLimit, double discTempDelayLimit, int discTempDelayTime,
      double discTempImmedLimit, double discTempLowImmedLimit, double heaterTempLimit,
      double liquidTempDelayLimit, int liquidTempDelayTime, double liquidTempImmedLimit,
      double orificeOffPress, double orificeOnPress, double phaseSepTempDelayLimit,
      int phaseSepTempDelayTime, double pressDiffImmedLimit, double suctTempImmedLimit) {
    super (priority);
    this.version = version;
    this.cmprPowerDelayLimit = cmprPowerDelayLimit;
    this.cmprPowerDelayTime = cmprPowerDelayTime;
    this.cmprPowerImmedLimit = cmprPowerImmedLimit;
    this.coldTempImmedLimit = coldTempImmedLimit;
    this.discPressDelayLimit = discPressDelayLimit;
    this.discPressDelayTime = discPressDelayTime;
    this.discPressImmedLimit = discPressImmedLimit;
    this.discTempDelayLimit = discTempDelayLimit;
    this.discTempDelayTime = discTempDelayTime;
    this.discTempImmedLimit = discTempImmedLimit;
    this.discTempLowImmedLimit = discTempLowImmedLimit;
    this.heaterTempLimit = heaterTempLimit;
    this.liquidTempDelayLimit = liquidTempDelayLimit;
    this.liquidTempDelayTime = liquidTempDelayTime;
    this.liquidTempImmedLimit = liquidTempImmedLimit;
    this.orificeOffPress = orificeOffPress;
    this.orificeOnPress = orificeOnPress;
    this.phaseSepTempDelayLimit = phaseSepTempDelayLimit;
    this.phaseSepTempDelayTime = phaseSepTempDelayTime;
    this.pressDiffImmedLimit = pressDiffImmedLimit;
    this.suctTempImmedLimit = suctTempImmedLimit;
  }

  public String getVersion() {
    return version;
  }

  public double getCmprPowerDelayLimit() {
    return cmprPowerDelayLimit;
  }

  public int getCmprPowerDelayTime() {
    return cmprPowerDelayTime;
  }

  public double getCmprPowerImmedLimit() {
    return cmprPowerImmedLimit;
  }

  public double getColdTempImmedLimit() {
    return coldTempImmedLimit;
  }

  public double getDiscPressDelayLimit() {
    return discPressDelayLimit;
  }

  public int getDiscPressDelayTime() {
    return discPressDelayTime;
  }

  public double getDiscPressImmedLimit() {
    return discPressImmedLimit;
  }

  public double getDiscTempDelayLimit() {
    return discTempDelayLimit;
  }

  public int getDiscTempDelayTime() {
    return discTempDelayTime;
  }

  public double getDiscTempImmedLimit() {
    return discTempImmedLimit;
  }

  public double getDiscTempLowImmedLimit() {
    return discTempLowImmedLimit;
  }

  public double getHeaterTempLimit() {
    return heaterTempLimit;
  }

  public double getLiquidTempDelayLimit() {
    return liquidTempDelayLimit;
  }

  public int getLiquidTempDelayTime() {
    return liquidTempDelayTime;
  }

  public double getLiquidTempImmedLimit() {
    return liquidTempImmedLimit;
  }

  public double getOrificeOffPress() {
    return orificeOffPress;
  }

  public double getOrificeOnPress() {
    return orificeOnPress;
  }

  public double getPhaseSepTempDelayLimit() {
    return phaseSepTempDelayLimit;
  }

  public int getPhaseSepTempDelayTime() {
    return phaseSepTempDelayTime;
  }

  public double getPressDiffImmedLimit() {
    return pressDiffImmedLimit;
  }

  public double getSuctTempImmedLimit() {
    return suctTempImmedLimit;
  }

  @Override
  public String toString() {
    return "Refrig_Cryo4_CompLimitsConfigurationEvent{" + "version=" + version +
        ", cmprPowerDelayLimit=" + cmprPowerDelayLimit +
        ", cmprPowerDelayTime=" + cmprPowerDelayTime +
        ", cmprPowerImmedLimit=" + cmprPowerImmedLimit +
        ", coldTempImmedLimit=" + coldTempImmedLimit +
        ", discPressDelayLimit=" + discPressDelayLimit +
        ", discPressDelayTime=" + discPressDelayTime +
        ", discPressImmedLimit=" + discPressImmedLimit +
        ", discTempDelayLimit=" + discTempDelayLimit +", discTempDelayTime=" + discTempDelayTime +
        ", discTempImmedLimit=" + discTempImmedLimit +
        ", discTempLowImmedLimit=" + discTempLowImmedLimit +", heaterTempLimit=" + heaterTempLimit +
        ", liquidTempDelayLimit=" + liquidTempDelayLimit +
        ", liquidTempDelayTime=" + liquidTempDelayTime +
        ", liquidTempImmedLimit=" + liquidTempImmedLimit +", orificeOffPress=" + orificeOffPress +
        ", orificeOnPress=" + orificeOnPress +", phaseSepTempDelayLimit=" + phaseSepTempDelayLimit +
        ", phaseSepTempDelayTime=" + phaseSepTempDelayTime +
        ", pressDiffImmedLimit=" + pressDiffImmedLimit +
        ", suctTempImmedLimit=" + suctTempImmedLimit +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private int priority;

    private String version;

    private double cmprPowerDelayLimit;

    private int cmprPowerDelayTime;

    private double cmprPowerImmedLimit;

    private double coldTempImmedLimit;

    private double discPressDelayLimit;

    private int discPressDelayTime;

    private double discPressImmedLimit;

    private double discTempDelayLimit;

    private int discTempDelayTime;

    private double discTempImmedLimit;

    private double discTempLowImmedLimit;

    private double heaterTempLimit;

    private double liquidTempDelayLimit;

    private int liquidTempDelayTime;

    private double liquidTempImmedLimit;

    private double orificeOffPress;

    private double orificeOnPress;

    private double phaseSepTempDelayLimit;

    private int phaseSepTempDelayTime;

    private double pressDiffImmedLimit;

    private double suctTempImmedLimit;

    private Builder() {
    }

    public Builder priority(int priority) {
      this.priority = priority;
      return this;
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder cmprPowerDelayLimit(double cmprPowerDelayLimit) {
      this.cmprPowerDelayLimit = cmprPowerDelayLimit;
      return this;
    }

    public Builder cmprPowerDelayTime(int cmprPowerDelayTime) {
      this.cmprPowerDelayTime = cmprPowerDelayTime;
      return this;
    }

    public Builder cmprPowerImmedLimit(double cmprPowerImmedLimit) {
      this.cmprPowerImmedLimit = cmprPowerImmedLimit;
      return this;
    }

    public Builder coldTempImmedLimit(double coldTempImmedLimit) {
      this.coldTempImmedLimit = coldTempImmedLimit;
      return this;
    }

    public Builder discPressDelayLimit(double discPressDelayLimit) {
      this.discPressDelayLimit = discPressDelayLimit;
      return this;
    }

    public Builder discPressDelayTime(int discPressDelayTime) {
      this.discPressDelayTime = discPressDelayTime;
      return this;
    }

    public Builder discPressImmedLimit(double discPressImmedLimit) {
      this.discPressImmedLimit = discPressImmedLimit;
      return this;
    }

    public Builder discTempDelayLimit(double discTempDelayLimit) {
      this.discTempDelayLimit = discTempDelayLimit;
      return this;
    }

    public Builder discTempDelayTime(int discTempDelayTime) {
      this.discTempDelayTime = discTempDelayTime;
      return this;
    }

    public Builder discTempImmedLimit(double discTempImmedLimit) {
      this.discTempImmedLimit = discTempImmedLimit;
      return this;
    }

    public Builder discTempLowImmedLimit(double discTempLowImmedLimit) {
      this.discTempLowImmedLimit = discTempLowImmedLimit;
      return this;
    }

    public Builder heaterTempLimit(double heaterTempLimit) {
      this.heaterTempLimit = heaterTempLimit;
      return this;
    }

    public Builder liquidTempDelayLimit(double liquidTempDelayLimit) {
      this.liquidTempDelayLimit = liquidTempDelayLimit;
      return this;
    }

    public Builder liquidTempDelayTime(int liquidTempDelayTime) {
      this.liquidTempDelayTime = liquidTempDelayTime;
      return this;
    }

    public Builder liquidTempImmedLimit(double liquidTempImmedLimit) {
      this.liquidTempImmedLimit = liquidTempImmedLimit;
      return this;
    }

    public Builder orificeOffPress(double orificeOffPress) {
      this.orificeOffPress = orificeOffPress;
      return this;
    }

    public Builder orificeOnPress(double orificeOnPress) {
      this.orificeOnPress = orificeOnPress;
      return this;
    }

    public Builder phaseSepTempDelayLimit(double phaseSepTempDelayLimit) {
      this.phaseSepTempDelayLimit = phaseSepTempDelayLimit;
      return this;
    }

    public Builder phaseSepTempDelayTime(int phaseSepTempDelayTime) {
      this.phaseSepTempDelayTime = phaseSepTempDelayTime;
      return this;
    }

    public Builder pressDiffImmedLimit(double pressDiffImmedLimit) {
      this.pressDiffImmedLimit = pressDiffImmedLimit;
      return this;
    }

    public Builder suctTempImmedLimit(double suctTempImmedLimit) {
      this.suctTempImmedLimit = suctTempImmedLimit;
      return this;
    }

    public Refrig_Cryo4_CompLimitsConfigurationEvent build() {
      return new Refrig_Cryo4_CompLimitsConfigurationEvent(priority, version, cmprPowerDelayLimit, cmprPowerDelayTime, cmprPowerImmedLimit, coldTempImmedLimit, discPressDelayLimit, discPressDelayTime, discPressImmedLimit, discTempDelayLimit, discTempDelayTime, discTempImmedLimit, discTempLowImmedLimit, heaterTempLimit, liquidTempDelayLimit, liquidTempDelayTime, liquidTempImmedLimit, orificeOffPress, orificeOnPress, phaseSepTempDelayLimit, phaseSepTempDelayTime, pressDiffImmedLimit, suctTempImmedLimit);
    }
  }
}

==> org-lsst-sal-camera-2.5.8-sources.jar: org/lsst/sal/camera/event/Refrig_Cryo4_CompLimitsConfigurationEvent.java <==
package org.lsst.sal.camera.event;

import org.lsst.sal.camera.CameraEvent;

public class Refrig_Cryo4_CompLimitsConfigurationEvent extends CameraEvent {
  private final String version;

  private final double cmprPowerDelayLimit;

  private final int cmprPowerDelayTime;

  private final double cmprPowerImmedLimit;

  private final double coldTempImmedLimit;

  private final double discPressDelayLimit;

  private final int discPressDelayTime;

  private final double discPressImmedLimit;

  private final double discTempDelayLimit;

  private final int discTempDelayTime;

  private final double discTempImmedLimit;

  private final double discTempLowImmedLimit;

  private final double heaterTempLimit;

  private final double liquidTempDelayLimit;

  private final int liquidTempDelayTime;

  private final double liquidTempImmedLimit;

  private final double orificeOffPress;

  private final double orificeOnPress;

  private final double phaseSepTempDelayLimit;

  private final int phaseSepTempDelayTime;

  private final double pressDiffImmedLimit;

  private final double suctTempImmedLimit;

  public Refrig_Cryo4_CompLimitsConfigurationEvent(String version, double cmprPowerDelayLimit,
      int cmprPowerDelayTime, double cmprPowerImmedLimit, double coldTempImmedLimit,
      double discPressDelayLimit, int discPressDelayTime, double discPressImmedLimit,
      double discTempDelayLimit, int discTempDelayTime, double discTempImmedLimit,
      double discTempLowImmedLimit, double heaterTempLimit, double liquidTempDelayLimit,
      int liquidTempDelayTime, double liquidTempImmedLimit, double orificeOffPress,
      double orificeOnPress, double phaseSepTempDelayLimit, int phaseSepTempDelayTime,
      double pressDiffImmedLimit, double suctTempImmedLimit) {
    this.version = version;
    this.cmprPowerDelayLimit = cmprPowerDelayLimit;
    this.cmprPowerDelayTime = cmprPowerDelayTime;
    this.cmprPowerImmedLimit = cmprPowerImmedLimit;
    this.coldTempImmedLimit = coldTempImmedLimit;
    this.discPressDelayLimit = discPressDelayLimit;
    this.discPressDelayTime = discPressDelayTime;
    this.discPressImmedLimit = discPressImmedLimit;
    this.discTempDelayLimit = discTempDelayLimit;
    this.discTempDelayTime = discTempDelayTime;
    this.discTempImmedLimit = discTempImmedLimit;
    this.discTempLowImmedLimit = discTempLowImmedLimit;
    this.heaterTempLimit = heaterTempLimit;
    this.liquidTempDelayLimit = liquidTempDelayLimit;
    this.liquidTempDelayTime = liquidTempDelayTime;
    this.liquidTempImmedLimit = liquidTempImmedLimit;
    this.orificeOffPress = orificeOffPress;
    this.orificeOnPress = orificeOnPress;
    this.phaseSepTempDelayLimit = phaseSepTempDelayLimit;
    this.phaseSepTempDelayTime = phaseSepTempDelayTime;
    this.pressDiffImmedLimit = pressDiffImmedLimit;
    this.suctTempImmedLimit = suctTempImmedLimit;
  }

  public String getVersion() {
    return version;
  }

  public double getCmprPowerDelayLimit() {
    return cmprPowerDelayLimit;
  }

  public int getCmprPowerDelayTime() {
    return cmprPowerDelayTime;
  }

  public double getCmprPowerImmedLimit() {
    return cmprPowerImmedLimit;
  }

  public double getColdTempImmedLimit() {
    return coldTempImmedLimit;
  }

  public double getDiscPressDelayLimit() {
    return discPressDelayLimit;
  }

  public int getDiscPressDelayTime() {
    return discPressDelayTime;
  }

  public double getDiscPressImmedLimit() {
    return discPressImmedLimit;
  }

  public double getDiscTempDelayLimit() {
    return discTempDelayLimit;
  }

  public int getDiscTempDelayTime() {
    return discTempDelayTime;
  }

  public double getDiscTempImmedLimit() {
    return discTempImmedLimit;
  }

  public double getDiscTempLowImmedLimit() {
    return discTempLowImmedLimit;
  }

  public double getHeaterTempLimit() {
    return heaterTempLimit;
  }

  public double getLiquidTempDelayLimit() {
    return liquidTempDelayLimit;
  }

  public int getLiquidTempDelayTime() {
    return liquidTempDelayTime;
  }

  public double getLiquidTempImmedLimit() {
    return liquidTempImmedLimit;
  }

  public double getOrificeOffPress() {
    return orificeOffPress;
  }

  public double getOrificeOnPress() {
    return orificeOnPress;
  }

  public double getPhaseSepTempDelayLimit() {
    return phaseSepTempDelayLimit;
  }

  public int getPhaseSepTempDelayTime() {
    return phaseSepTempDelayTime;
  }

  public double getPressDiffImmedLimit() {
    return pressDiffImmedLimit;
  }

  public double getSuctTempImmedLimit() {
    return suctTempImmedLimit;
  }

  @Override
  public String toString() {
    return "Refrig_Cryo4_CompLimitsConfigurationEvent{" + "version=" + version +
        ", cmprPowerDelayLimit=" + cmprPowerDelayLimit +
        ", cmprPowerDelayTime=" + cmprPowerDelayTime +
        ", cmprPowerImmedLimit=" + cmprPowerImmedLimit +
        ", coldTempImmedLimit=" + coldTempImmedLimit +
        ", discPressDelayLimit=" + discPressDelayLimit +
        ", discPressDelayTime=" + discPressDelayTime +
        ", discPressImmedLimit=" + discPressImmedLimit +
        ", discTempDelayLimit=" + discTempDelayLimit +", discTempDelayTime=" + discTempDelayTime +
        ", discTempImmedLimit=" + discTempImmedLimit +
        ", discTempLowImmedLimit=" + discTempLowImmedLimit +", heaterTempLimit=" + heaterTempLimit +
        ", liquidTempDelayLimit=" + liquidTempDelayLimit +
        ", liquidTempDelayTime=" + liquidTempDelayTime +
        ", liquidTempImmedLimit=" + liquidTempImmedLimit +", orificeOffPress=" + orificeOffPress +
        ", orificeOnPress=" + orificeOnPress +", phaseSepTempDelayLimit=" + phaseSepTempDelayLimit +
        ", phaseSepTempDelayTime=" + phaseSepTempDelayTime +
        ", pressDiffImmedLimit=" + pressDiffImmedLimit +
        ", suctTempImmedLimit=" + suctTempImmedLimit +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private String version;

    private double cmprPowerDelayLimit;

    private int cmprPowerDelayTime;

    private double cmprPowerImmedLimit;

    private double coldTempImmedLimit;

    private double discPressDelayLimit;

    private int discPressDelayTime;

    private double discPressImmedLimit;

    private double discTempDelayLimit;

    private int discTempDelayTime;

    private double discTempImmedLimit;

    private double discTempLowImmedLimit;

    private double heaterTempLimit;

    private double liquidTempDelayLimit;

    private int liquidTempDelayTime;

    private double liquidTempImmedLimit;

    private double orificeOffPress;

    private double orificeOnPress;

    private double phaseSepTempDelayLimit;

    private int phaseSepTempDelayTime;

    private double pressDiffImmedLimit;

    private double suctTempImmedLimit;

    private Builder() {
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder cmprPowerDelayLimit(double cmprPowerDelayLimit) {
      this.cmprPowerDelayLimit = cmprPowerDelayLimit;
      return this;
    }

    public Builder cmprPowerDelayTime(int cmprPowerDelayTime) {
      this.cmprPowerDelayTime = cmprPowerDelayTime;
      return this;
    }

    public Builder cmprPowerImmedLimit(double cmprPowerImmedLimit) {
      this.cmprPowerImmedLimit = cmprPowerImmedLimit;
      return this;
    }

    public Builder coldTempImmedLimit(double coldTempImmedLimit) {
      this.coldTempImmedLimit = coldTempImmedLimit;
      return this;
    }

    public Builder discPressDelayLimit(double discPressDelayLimit) {
      this.discPressDelayLimit = discPressDelayLimit;
      return this;
    }

    public Builder discPressDelayTime(int discPressDelayTime) {
      this.discPressDelayTime = discPressDelayTime;
      return this;
    }

    public Builder discPressImmedLimit(double discPressImmedLimit) {
      this.discPressImmedLimit = discPressImmedLimit;
      return this;
    }

    public Builder discTempDelayLimit(double discTempDelayLimit) {
      this.discTempDelayLimit = discTempDelayLimit;
      return this;
    }

    public Builder discTempDelayTime(int discTempDelayTime) {
      this.discTempDelayTime = discTempDelayTime;
      return this;
    }

    public Builder discTempImmedLimit(double discTempImmedLimit) {
      this.discTempImmedLimit = discTempImmedLimit;
      return this;
    }

    public Builder discTempLowImmedLimit(double discTempLowImmedLimit) {
      this.discTempLowImmedLimit = discTempLowImmedLimit;
      return this;
    }

    public Builder heaterTempLimit(double heaterTempLimit) {
      this.heaterTempLimit = heaterTempLimit;
      return this;
    }

    public Builder liquidTempDelayLimit(double liquidTempDelayLimit) {
      this.liquidTempDelayLimit = liquidTempDelayLimit;
      return this;
    }

    public Builder liquidTempDelayTime(int liquidTempDelayTime) {
      this.liquidTempDelayTime = liquidTempDelayTime;
      return this;
    }

    public Builder liquidTempImmedLimit(double liquidTempImmedLimit) {
      this.liquidTempImmedLimit = liquidTempImmedLimit;
      return this;
    }

    public Builder orificeOffPress(double orificeOffPress) {
      this.orificeOffPress = orificeOffPress;
      return this;
    }

    public Builder orificeOnPress(double orificeOnPress) {
      this.orificeOnPress = orificeOnPress;
      return this;
    }

    public Builder phaseSepTempDelayLimit(double phaseSepTempDelayLimit) {
      this.phaseSepTempDelayLimit = phaseSepTempDelayLimit;
      return this;
    }

    public Builder phaseSepTempDelayTime(int phaseSepTempDelayTime) {
      this.phaseSepTempDelayTime = phaseSepTempDelayTime;
      return this;
    }

    public Builder pressDiffImmedLimit(double pressDiffImmedLimit) {
      this.pressDiffImmedLimit = pressDiffImmedLimit;
      return this;
    }

    public Builder suctTempImmedLimit(double suctTempImmedLimit) {
      this.suctTempImmedLimit = suctTempImmedLimit;
      return this;
    }

    public Refrig_Cryo4_CompLimitsConfigurationEvent build() {
      return new Refrig_Cryo4_CompLimitsConfigurationEvent(version, cmprPowerDelayLimit, cmprPowerDelayTime, cmprPowerImmedLimit, coldTempImmedLimit, discPressDelayLimit, discPressDelayTime, discPressImmedLimit, discTempDelayLimit, discTempDelayTime, discTempImmedLimit, discTempLowImmedLimit, heaterTempLimit, liquidTempDelayLimit, liquidTempDelayTime, liquidTempImmedLimit, orificeOffPress, orificeOnPress, phaseSepTempDelayLimit, phaseSepTempDelayTime, pressDiffImmedLimit, suctTempImmedLimit);
    }
  }
}
